Index: /branches/eam_branches/ipp-20120601/Ohana/src/addstar/src/GetFileMode.c
===================================================================
--- /branches/eam_branches/ipp-20120601/Ohana/src/addstar/src/GetFileMode.c	(revision 33981)
+++ /branches/eam_branches/ipp-20120601/Ohana/src/addstar/src/GetFileMode.c	(revision 33982)
@@ -7,10 +7,10 @@
 
   int Naxis;
-  int simple, extend, haveNaxis, haveCTYPE;
+  int simple, extend;
   int havePHOT_VER, haveTARG_VER;
 
   gfits_scan_alt (header, "SIMPLE", "%t", 1, &simple);
-  haveNaxis = gfits_scan (header, "NAXIS",  "%d", 1, &Naxis);
-  haveCTYPE = gfits_scan (header, "CTYPE1", "%s", 1, ctype);
+  int haveNaxis = gfits_scan (header, "NAXIS",  "%d", 1, &Naxis);
+  int haveCTYPE = gfits_scan (header, "CTYPE1", "%s", 1, ctype);
 
   gfits_scan_alt (header, "EXTEND", "%t", 1, &extend);
@@ -22,6 +22,6 @@
   if (havePHOT_VER && haveTARG_VER) return SDSS_OBJ;
 
-  if ((Naxis == 2) || TEXTMODE || !simple) {
-    if (!strcmp (&ctype[4], "-WRP")) {
+  if (haveNaxis && ((Naxis == 2) || TEXTMODE || !simple)) {
+    if (haveCTYPE && !strcmp (&ctype[4], "-WRP")) {
       return MOSAIC_CMP;
     }
Index: /branches/eam_branches/ipp-20120601/Ohana/src/addstar/src/edge_check.c
===================================================================
--- /branches/eam_branches/ipp-20120601/Ohana/src/addstar/src/edge_check.c	(revision 33981)
+++ /branches/eam_branches/ipp-20120601/Ohana/src/addstar/src/edge_check.c	(revision 33982)
@@ -4,5 +4,4 @@
 
   double theta1, theta2;
-  double Theta1, Theta2;
 
   theta1 = opening_angle (x1[0], y1[0], x2[0], y2[0], x1[1], y1[1]); 
@@ -17,6 +16,4 @@
   }
 
-  Theta1 = theta1;
-  Theta2 = theta2;
   theta1 = opening_angle (x2[0], y2[0], x1[1], y1[1], x2[1], y2[1]); 
   theta2 = opening_angle (x2[0], y2[0], x1[1], y1[1], x1[0], y1[0]); 
Index: /branches/eam_branches/ipp-20120601/Ohana/src/addstar/src/get2mass_full.c
===================================================================
--- /branches/eam_branches/ipp-20120601/Ohana/src/addstar/src/get2mass_full.c	(revision 33981)
+++ /branches/eam_branches/ipp-20120601/Ohana/src/addstar/src/get2mass_full.c	(revision 33982)
@@ -23,7 +23,7 @@
   star[0][0].measure.theta = ToShortPixels(strtod (ptr, NULL));
 
-  star[2][0].measure.FWx   = star[2][0].measure.FWx   = star[0][0].measure.FWx;
-  star[2][0].measure.FWy   = star[2][0].measure.FWy   = star[0][0].measure.FWy;
-  star[2][0].measure.theta = star[2][0].measure.theta = star[0][0].measure.theta;
+  star[2][0].measure.FWx   = star[1][0].measure.FWx   = star[0][0].measure.FWx;
+  star[2][0].measure.FWy   = star[1][0].measure.FWy   = star[0][0].measure.FWy;
+  star[2][0].measure.theta = star[1][0].measure.theta = star[0][0].measure.theta;
 
   ptr = next2MASSfield (ptr); // designation (skip)
Index: /branches/eam_branches/ipp-20120601/Ohana/src/addstar/src/load2mass_as_rawdata.c
===================================================================
--- /branches/eam_branches/ipp-20120601/Ohana/src/addstar/src/load2mass_as_rawdata.c	(revision 33981)
+++ /branches/eam_branches/ipp-20120601/Ohana/src/addstar/src/load2mass_as_rawdata.c	(revision 33982)
@@ -14,5 +14,5 @@
   int i, j, verbose;
   int Nstars, NSTARS, Ntstars, NTSTARS;
-  int Nbyte, Nextra, Ntotal, offset;
+  int Nbyte, Nextra, offset;
 
   double Rmin, Rmax, Dmin, Dmax;
@@ -37,5 +37,4 @@
 
   Nextra = 0;  // number excess bytes from lsat partial row
-  Ntotal = 0;  // track the total number of bytes read 
   while ((Nbyte = fread (&buffer[Nextra], 1, NBYTE-Nextra, f)) != 0) {
     if (Nbyte == -1) Shutdown ("error reading from raw file %s", filename);
Index: /branches/eam_branches/ipp-20120601/Ohana/src/addstar/src/load_subpix.c
===================================================================
--- /branches/eam_branches/ipp-20120601/Ohana/src/addstar/src/load_subpix.c	(revision 33981)
+++ /branches/eam_branches/ipp-20120601/Ohana/src/addstar/src/load_subpix.c	(revision 33982)
@@ -45,7 +45,7 @@
 
   int bin;
-  double dy, dM;
+  double dM;
 
-  dy = y - (int)(y);
+  // dy = y - (int)(y);
   bin = 5 * (int)(x/100) + (int)(y/100);
   dM = Subpix[bin].dM;
Index: /branches/eam_branches/ipp-20120601/Ohana/src/addstar/src/resort_catalog.c
===================================================================
--- /branches/eam_branches/ipp-20120601/Ohana/src/addstar/src/resort_catalog.c	(revision 33981)
+++ /branches/eam_branches/ipp-20120601/Ohana/src/addstar/src/resort_catalog.c	(revision 33982)
@@ -146,5 +146,5 @@
   int NmeasureTotal = 0;
   int measureOffsetOK = TRUE;
-  for (i = 0; i < catalog[0].Naverage; i++) {
+  for (i = 0; i < Naverage; i++) {
     NmeasureTotal += catalog[0].average[i].Nmeasure;
     if (VERBOSE && !(NmeasureTotal <= catalog[0].Nmeasure)) {
Index: /branches/eam_branches/ipp-20120601/Ohana/src/libdvo/src/ImageOps.c
===================================================================
--- /branches/eam_branches/ipp-20120601/Ohana/src/libdvo/src/ImageOps.c	(revision 33981)
+++ /branches/eam_branches/ipp-20120601/Ohana/src/libdvo/src/ImageOps.c	(revision 33982)
@@ -8,5 +8,5 @@
 {
 
-  int j, flipped, status, InPic;
+  int j, flipped, status;
   off_t i, n, *subset;
   int npts;
@@ -65,5 +65,5 @@
       x[2] = image[i].NX; y[2] = image[i].NY;
       x[3] = 0;           y[3] = image[i].NY;
-      InPic = flipped = FALSE;
+      flipped = FALSE;
       for (j = 0; j < 4; j++) {
 	XY_to_RD (&r, &d, x[j], y[j], &image[i].coords);
@@ -95,5 +95,5 @@
       x[2] = image[i].NX; y[2] = image[i].NY;
       x[3] = 0;           y[3] = image[i].NY;
-      InPic = flipped = FALSE;
+      flipped = FALSE;
       for (j = 0; j < 4; j++) {
 	XY_to_RD (&r, &d, x[j], y[j], &image[i].coords);
Index: /branches/eam_branches/ipp-20120601/Ohana/src/libdvo/src/coordops.c
===================================================================
--- /branches/eam_branches/ipp-20120601/Ohana/src/libdvo/src/coordops.c	(revision 33981)
+++ /branches/eam_branches/ipp-20120601/Ohana/src/libdvo/src/coordops.c	(revision 33982)
@@ -68,5 +68,5 @@
   mode = GetProjectionMode (proj);
   if (proj == PROJ_NONE) return (FALSE);
-  if (proj == PROJ_MODE_NONE) return (FALSE);
+  if (mode == PROJ_MODE_NONE) return (FALSE);
 
   stht = ctht = 1;
@@ -201,5 +201,5 @@
   mode = GetProjectionMode (proj);
   if (proj == PROJ_NONE) return (FALSE);
-  if (proj == PROJ_MODE_NONE) return (FALSE);
+  if (mode == PROJ_MODE_NONE) return (FALSE);
 
   /**** Locally Cartesian Projections ****/
Index: /branches/eam_branches/ipp-20120601/Ohana/src/libdvo/src/dbCmdlineFields.c
===================================================================
--- /branches/eam_branches/ipp-20120601/Ohana/src/libdvo/src/dbCmdlineFields.c	(revision 33981)
+++ /branches/eam_branches/ipp-20120601/Ohana/src/libdvo/src/dbCmdlineFields.c	(revision 33982)
@@ -136,7 +136,7 @@
     // XXX the ra and dec range depend on the projection. 
     // XXX this is wrong...
-    int status;
-    status = XY_to_RD (&Rmin, &Dmin, graphsky.xmin, graphsky.ymin, &graphsky.coords);
-    status = XY_to_RD (&Rmax, &Dmax, graphsky.xmax, graphsky.ymax, &graphsky.coords);
+    // int status;
+    XY_to_RD (&Rmin, &Dmin, graphsky.xmin, graphsky.ymin, &graphsky.coords);
+    XY_to_RD (&Rmax, &Dmax, graphsky.xmax, graphsky.ymax, &graphsky.coords);
   }
 
Index: /branches/eam_branches/ipp-20120601/Ohana/src/libdvo/src/dbRPN.c
===================================================================
--- /branches/eam_branches/ipp-20120601/Ohana/src/libdvo/src/dbRPN.c	(revision 33981)
+++ /branches/eam_branches/ipp-20120601/Ohana/src/libdvo/src/dbRPN.c	(revision 33982)
@@ -4,5 +4,5 @@
 dbStack *dbRPN (int argc, char **argv, int *nstack) {
   
-  int type, Nx, Ny;
+  int type;
   int i, j, Nstack, Nop_stack, NSTACK;
   dbStack *stack, *op_stack;
@@ -17,5 +17,5 @@
   }
   
-  Nx = Ny = Nstack = Nop_stack = 0;
+  Nstack = Nop_stack = 0;
   for (i = 0; i < argc; i++) {
     
Index: /branches/eam_branches/ipp-20120601/Ohana/src/libdvo/src/dvo_image.c
===================================================================
--- /branches/eam_branches/ipp-20120601/Ohana/src/libdvo/src/dvo_image.c	(revision 33981)
+++ /branches/eam_branches/ipp-20120601/Ohana/src/libdvo/src/dvo_image.c	(revision 33982)
@@ -111,5 +111,5 @@
       exit (2);
   }
-  return (TRUE);
+  return (status);
 }
 
Index: /branches/eam_branches/ipp-20120601/Ohana/src/libdvo/src/dvo_tiny_values.c
===================================================================
--- /branches/eam_branches/ipp-20120601/Ohana/src/libdvo/src/dvo_tiny_values.c	(revision 33981)
+++ /branches/eam_branches/ipp-20120601/Ohana/src/libdvo/src/dvo_tiny_values.c	(revision 33982)
@@ -51,5 +51,5 @@
 
     for (i = 0; i < catalog[0].Naverage; i++) {
-      CopyAverageToTiny (&catalog[0].averageT[i], &catalog[0].average[i]);
+      CopyAverageToTiny (&averageT[i], &average[i]);
     }
   }
@@ -61,5 +61,5 @@
 
     for (i = 0; i < catalog[0].Nmeasure; i++) {
-      CopyMeasureToTiny (&catalog[0].measureT[i], &catalog[0].measure[i]);
+      CopyMeasureToTiny (&measureT[i], &measure[i]);
     }
   }
Index: /branches/eam_branches/ipp-20120601/Ohana/src/libdvo/src/skyregion_gsc.c
===================================================================
--- /branches/eam_branches/ipp-20120601/Ohana/src/libdvo/src/skyregion_gsc.c	(revision 33981)
+++ /branches/eam_branches/ipp-20120601/Ohana/src/libdvo/src/skyregion_gsc.c	(revision 33982)
@@ -271,5 +271,4 @@
   int i, j, Nz, NZ, Nregions, poleRegion;
   SkyRegion *regions;
-  SkyRegion tempregion;
   SkyRegionZone *zones;
   char basename[64];
@@ -294,5 +293,4 @@
       poleRegion = SIGN(regions[i].Dmin);
       Nregions --;
-      tempregion = regions[i];
       for (j = i; j < Nregions; j++) {
 	regions[j] = regions[j+1];
Index: /branches/eam_branches/ipp-20120601/Ohana/src/libfits/extern/fits_hdecompress.c
===================================================================
--- /branches/eam_branches/ipp-20120601/Ohana/src/libfits/extern/fits_hdecompress.c	(revision 33981)
+++ /branches/eam_branches/ipp-20120601/Ohana/src/libfits/extern/fits_hdecompress.c	(revision 33982)
@@ -1048,5 +1048,5 @@
 {
 LONGLONG sumall;
-int nel, stat;
+int stat;
 unsigned char nbitplanes[3];
 char tmagic[2];
@@ -1071,5 +1071,5 @@
 	*scale=readint(infile);				/* scale factor for digitization	*/
 	
-	nel = (*nx) * (*ny);
+	// nel = (*nx) * (*ny);
 
 	/* sum of all pixels	*/
@@ -1095,5 +1095,5 @@
 */
 {
-int nel, stat;
+int stat;
 LONGLONG sumall;
 unsigned char nbitplanes[3];
@@ -1119,5 +1119,5 @@
 	*scale=readint(infile);				/* scale factor for digitization	*/
 	
-	nel = (*nx) * (*ny);
+	// nel = (*nx) * (*ny);
 
 	/* sum of all pixels	*/
Index: /branches/eam_branches/ipp-20120601/Ohana/src/libfits/extern/ricecomp.c
===================================================================
--- /branches/eam_branches/ipp-20120601/Ohana/src/libfits/extern/ricecomp.c	(revision 33981)
+++ /branches/eam_branches/ipp-20120601/Ohana/src/libfits/extern/ricecomp.c	(revision 33982)
@@ -59,5 +59,5 @@
 {
 Buffer bufmem, *buffer = &bufmem;
-int bsize, i, j, thisblock;
+int i, j, thisblock;
 int lastpix, nextpix, pdiff;
 int v, fs, fsmask, top, fsmax, fsbits, bbits;
@@ -73,5 +73,5 @@
      * compression of short & byte images.
      */
-    bsize = 4;
+// int bsize = 4;
 
 /*    nblock = 32; now an input parameter*/
@@ -277,5 +277,5 @@
 {
 Buffer bufmem, *buffer = &bufmem;
-int bsize, i, j, thisblock;
+int i, j, thisblock;
 
 /* 
@@ -299,5 +299,5 @@
      * compression of short & byte images.
      */
-    bsize = 2;
+// bsize = 2;
 
 /*    nblock = 32; now an input parameter */
@@ -501,5 +501,5 @@
 {
 Buffer bufmem, *buffer = &bufmem;
-int bsize, i, j, thisblock;
+int i, j, thisblock;
 
 /* 
@@ -523,5 +523,5 @@
      * compression of short & byte images.
      */
-    bsize = 1;
+    // bsize = 1;
 
 /*    nblock = 32; now an input parameter */
@@ -826,5 +826,5 @@
 	     int nblock)		/* coding block size		*/
 {
-int bsize, i, k, imax;
+int i, k, imax;
 int nbits, nzero, fs;
 unsigned char *cend, bytevalue;
@@ -839,5 +839,5 @@
      * compression of short & byte images.
      */
-    bsize = 4;
+// bsize = 4;
 
 /*    nblock = 32; now an input parameter */
@@ -1014,5 +1014,5 @@
 {
 int i, imax;
-int bsize, k;
+int k;
 int nbits, nzero, fs;
 unsigned char *cend, bytevalue;
@@ -1028,5 +1028,5 @@
      */
 
-    bsize = 2;
+// bsize = 2;
     
 /*    nblock = 32; now an input parameter */
@@ -1200,5 +1200,5 @@
 {
 int i, imax;
-int bsize, k;
+int k;
 int nbits, nzero, fs;
 unsigned char *cend;
@@ -1214,5 +1214,5 @@
      */
 
-    bsize = 1;
+// bsize = 1;
     
 /*    nblock = 32; now an input parameter */
Index: /branches/eam_branches/ipp-20120601/Ohana/src/libfits/matrix/F_compress_M.c
===================================================================
--- /branches/eam_branches/ipp-20120601/Ohana/src/libfits/matrix/F_compress_M.c	(revision 33981)
+++ /branches/eam_branches/ipp-20120601/Ohana/src/libfits/matrix/F_compress_M.c	(revision 33982)
@@ -45,5 +45,5 @@
   float zscale, zzero;
 
-  int zdata_pixsize, odata_pixsize, idata_pixsize;
+  int zdata_pixsize, odata_pixsize;
 
   int *ztile = NULL;
@@ -236,6 +236,6 @@
   zdata_pixsize = gfits_vartable_heap_pixsize (zdef.format);
 
-  // size of a pixel in the final image
-  idata_pixsize = abs(header[0].bitpix) / 8;
+  // size of a pixel in the final image (not needed)
+  // idata_pixsize = abs(header[0].bitpix) / 8;
 
   // size of a pixel in the output from the decompression routine
@@ -480,9 +480,9 @@
 int gfits_compressed_is_primary (Header *header) {
 
-    int has_ztension, has_zimage;
-    int ztension, zimage;
-
-    has_zimage   = gfits_scan_alt (header, "ZIMAGE",   "%t", 1, &zimage);
-    has_ztension = gfits_scan_alt (header, "ZTENSION", "%t", 1, &ztension);
+  int zimage = FALSE;
+  // int ztension = FALSE;
+
+    int has_zimage   = gfits_scan_alt (header, "ZIMAGE",   "%t", 1, &zimage);
+    // int has_ztension = gfits_scan_alt (header, "ZTENSION", "%t", 1, &ztension);
 
     if (has_zimage && zimage) return (TRUE);
Index: /branches/eam_branches/ipp-20120601/Ohana/src/libfits/table/F_copy_T.c
===================================================================
--- /branches/eam_branches/ipp-20120601/Ohana/src/libfits/table/F_copy_T.c	(revision 33981)
+++ /branches/eam_branches/ipp-20120601/Ohana/src/libfits/table/F_copy_T.c	(revision 33982)
@@ -17,9 +17,9 @@
 int gfits_copy_vtable (VTable *in, VTable *out) {
 
-  off_t i, Nx, Ny, Nrows;
+  off_t i;
 
   /* find buffer size */
-  Nx = in[0].header[0].Naxis[0];
-  Ny = in[0].header[0].Naxis[1];
+  off_t Nx = in[0].header[0].Naxis[0];
+  // off_t Ny = in[0].header[0].Naxis[1];
 
   // validate these two?
@@ -32,5 +32,5 @@
   out[0].Nrow     = in[0].Nrow;
 
-  Nrows = out[0].Nrow;
+  off_t Nrows = out[0].Nrow;
 
   ALLOCATE (out[0].row, off_t, MAX (Nrows, 1));
Index: /branches/eam_branches/ipp-20120601/Ohana/src/libkapa/src/DrawRotString.c
===================================================================
--- /branches/eam_branches/ipp-20120601/Ohana/src/libkapa/src/DrawRotString.c	(revision 33981)
+++ /branches/eam_branches/ipp-20120601/Ohana/src/libkapa/src/DrawRotString.c	(revision 33982)
@@ -137,5 +137,5 @@
 
   int ii, jj, byte_line, byte, bit, flag;
-  unsigned long int fore, back;
+  unsigned long int fore;
   double i, j, cs, sn, rscale, tmp;
   int X, Y, X0, X1, X2, Y0, Y1, Y2, x0, y0;
@@ -143,8 +143,8 @@
   if (mode) {
     fore = RotForeground;
-    back = RotBackground;
+    // back = RotBackground;
   } else {
     fore = RotBackground;
-    back = RotForeground;
+    // back = RotForeground;
   } 
     
Index: /branches/eam_branches/ipp-20120601/Ohana/src/libkapa/src/KapaOpen.c
===================================================================
--- /branches/eam_branches/ipp-20120601/Ohana/src/libkapa/src/KapaOpen.c	(revision 33981)
+++ /branches/eam_branches/ipp-20120601/Ohana/src/libkapa/src/KapaOpen.c	(revision 33982)
@@ -252,5 +252,5 @@
 int KapaOpenNamedSocket (char *kapa_exec, char *name) {
 
-  int InitSocket, status;
+  int InitSocket;
   struct sockaddr_un Address;
   socklen_t AddressLength;
@@ -269,6 +269,6 @@
   Address.sun_family = AF_UNIX;
   InitSocket = socket (AF_UNIX, SOCK_STREAM, 0);
-  status = bind (InitSocket, (struct sockaddr *) &Address, sizeof (Address));
-  status = listen (InitSocket, 1);
+  bind (InitSocket, (struct sockaddr *) &Address, sizeof (Address));
+  listen (InitSocket, 1);
 
   if (name == NULL) {
Index: /branches/eam_branches/ipp-20120601/Ohana/src/libkapa/src/KiiOpen.c
===================================================================
--- /branches/eam_branches/ipp-20120601/Ohana/src/libkapa/src/KiiOpen.c	(revision 33981)
+++ /branches/eam_branches/ipp-20120601/Ohana/src/libkapa/src/KiiOpen.c	(revision 33982)
@@ -4,5 +4,5 @@
 int KiiOpen (char *kii_exec, char *name) {
 
-  int InitSocket, status;
+  int InitSocket;
   struct sockaddr_un Address;
   socklen_t AddressLength;
@@ -21,6 +21,6 @@
   Address.sun_family = AF_UNIX; 
   InitSocket = socket (AF_UNIX, SOCK_STREAM, 0); 
-  status = bind (InitSocket, (struct sockaddr *) &Address, sizeof (Address));
-  status = listen (InitSocket, 1);
+  bind (InitSocket, (struct sockaddr *) &Address, sizeof (Address));
+  listen (InitSocket, 1);
   
   if (name == NULL) {
Index: /branches/eam_branches/ipp-20120601/Ohana/src/libkapa/src/KiiPicture.c
===================================================================
--- /branches/eam_branches/ipp-20120601/Ohana/src/libkapa/src/KiiPicture.c	(revision 33981)
+++ /branches/eam_branches/ipp-20120601/Ohana/src/libkapa/src/KiiPicture.c	(revision 33982)
@@ -22,5 +22,5 @@
 
   int Nwrite, Npix, Ncolors, size;
-  float *in, min, max;
+  float min, max;
 
   Npix = image[0].Nx*image[0].Ny;
@@ -28,6 +28,4 @@
   KiiSendCommand (fd, 4, "READ"); /* tell kapa to look for the incoming image */
   KiiScanMessage (fd, "%d", &Ncolors);
-
-  in = image[0].data1d;
 
   /* these are for a future upgrade */
Index: /branches/eam_branches/ipp-20120601/Ohana/src/libohana/src/config.c
===================================================================
--- /branches/eam_branches/ipp-20120601/Ohana/src/libohana/src/config.c	(revision 33981)
+++ /branches/eam_branches/ipp-20120601/Ohana/src/libohana/src/config.c	(revision 33982)
@@ -131,5 +131,5 @@
   
   FILE *f;
-  int i, done, Nbytes, NBYTES, nbytes, Nout, Ncpy, INPUT, Nlevel;
+  int i, Nbytes, NBYTES, nbytes, Nout, Ncpy, INPUT, Nlevel;
   char *ibuffer, *obuffer, *tbuffer;
   char *last, *next;
@@ -149,5 +149,4 @@
   /* load data from file */
   if (f) {
-    done = FALSE;
     while ((nbytes = fread (&ibuffer[Nbytes], sizeof(char), D_NBYTES, f)) == D_NBYTES) {
       Nbytes += nbytes;
@@ -382,5 +381,5 @@
   
   FILE *f;
-  int i, done, Nbytes, NBYTES, nbytes, Ncpy;
+  int i, Nbytes, NBYTES, nbytes, Ncpy;
   char *ibuffer;
   char line[256];
@@ -398,5 +397,4 @@
     
   /* load data from file */
-  done = FALSE;
   while ((nbytes = fread (&ibuffer[Nbytes], sizeof(char), D_NBYTES, f)) == D_NBYTES) {
     Nbytes += nbytes;
Index: /branches/eam_branches/ipp-20120601/Ohana/src/libohana/src/time.c
===================================================================
--- /branches/eam_branches/ipp-20120601/Ohana/src/libohana/src/time.c	(revision 33981)
+++ /branches/eam_branches/ipp-20120601/Ohana/src/libohana/src/time.c	(revision 33982)
@@ -90,9 +90,9 @@
 
   char *p1, *p2;
-  double tmp;
+  // double tmp;
   int mode;
 
   p1 = line;
-  tmp = strtod (p1, &p2);
+  strtod (p1, &p2);
   mode = TIME_DATE;
   if (p2 == p1 + strlen (p1) - 1) {

Index: /branches/eam_branches/ipp-20120601/Ohana/src/addstar/src/get2mass_ops.c
===================================================================
--- /branches/eam_branches/ipp-20120601/Ohana/src/addstar/src/get2mass_ops.c	(revision 33981)
+++ /branches/eam_branches/ipp-20120601/Ohana/src/addstar/src/get2mass_ops.c	(revision 33982)
@@ -95,5 +95,9 @@
   dK = strtod (ptr, NULL);
 
-  /* filter on the ph_qual flag for this filter (field 19) */
+  // get the time
+  time = get2mass_time (ptr, 20, Nmax - (ptr - line));
+
+# if (0)
+  /* old code to filter on the ph_qual flag for this filter (field 19) */
   if (SELECT_2MASS_QUALITY != NULL) {
     ptr = skipNbounds (ptr, '|', 3, Nmax - (ptr - line));
@@ -105,4 +109,5 @@
     time = get2mass_time (ptr, 20, Nmax - (ptr - line));
   }
+# endif
 
   // how many bits are being used for the 2mass flags; can we just set photFlags based on them?